@@ -1,10 +1,6 @@
 import tensorflow.compat.v1 as tf
 import sys
-from pathlib import Path
-# To import upper level modules
-sys.path.append(str(Path('.').absolute().parent))
 import logging
-from keras_radam.training import RAdamOptimizer
 
 class InferCodeModel():
     LOGGER = logging.getLogger('InferCodeModel')
@@ -33,7 +29,7 @@ class InferCodeModel():
 
         self.batch_size = batch_size
 
-        self.optimizer = RAdamOptimizer(learning_rate)
+        self.optimizer = tf.compat.v1.train.AdamOptimizer(learning_rate)
 
         self.init_net()
         self.feed_forward()
@@ -153,7 +149,7 @@ class InferCodeModel():
                                                               biases=self.weights["subtree_embeddings_bias"], 
                                                               labels=self.placeholders["labels"], 
                                                               inputs=self.code_vector, 
-                                                              num_sampled=300, 
+                                                              num_sampled=200, 
                                                               num_classes=self.num_subtrees)
             self.loss = tf.reduce_mean(input_tensor=self.sampled_softmax_loss)
             # self.loss = self.sampled_softmax_loss + 0.1*self.language_label_loss
